Re: [PATCH/RFC v3 7/9] write_entry(): use fstat() instead of lstat() when file is open
- From
Johannes Schindelin <johannes.schindelin@gmx.de>
- Date
- Feb 5, 2009, 11:03 UTC
- Message-ID
- <alpine.DEB.1.00.0902051202440.7491@intel-tinevez-2-302>
- In-Reply-To
- <498A9FD3.2020601@viscovery.net>
Hi,
On Thu, 5 Feb 2009, Johannes Sixt wrote:
Show 13 quoted lines
> Kjetil Barvik schrieb: > > And, yes, since each lstat() call cost approximately 44 microseconds > > compared to 12-16 for each lstat() on my Linux box, there was a little > ^^^^^^^ fstat()? > > performance gain from this patch. > > This does look like a good gain. But do you have hard numbers that back > the claim? > > If you can squeeze out a 10% improvement on Linux with this patch, we > should take it, and if it turns out that it doesn't work on Windows, we > could trivially throw in an #ifdef MINGW (or even #ifdef WIN32 if Cygwin > is affected, too) that skips the fstat() optimization.
Of course, what we _really_ would do is to provide a flag, say, FSTAT_UNRELIABLE and test for _that_ (after defining it in the Makefile for the appropriate platforms).
Ciao, Dscho